@@ -8,9 +8,9 @@
 # <<< EXECUTE_SUCCESS: 'have $greetings->[-3] = hello' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
